import React from 'react'
import { NavLink } from 'react-router-dom'
import { translate } from 'cozy-ui/react/I18n'
import { FluidType } from 'enum/fluid.enum'
import { getPicto } from 'utils/utils'
import { IPerformanceIndicator } from 'services/dataConsumptionContracts'
import StyledCard from 'components/CommonKit/Card/StyledCard'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import BlackArrowIcon from 'assets/icons/ico/black-arrow.svg'
import { formatNumberValues } from 'utils/utils'

interface FluidPerformanceIndicatorProps {
  performanceIndicator: IPerformanceIndicator
  timePeriodText: string
  fluidType: FluidType
  t: any
}

const FluidPerformanceIndicator: React.FC<FluidPerformanceIndicatorProps> = ({
  performanceIndicator,
  timePeriodText,
  fluidType,
  t,
}: FluidPerformanceIndicatorProps) => {
  const iconType = getPicto(fluidType)

  let displayedValue: string
  if (performanceIndicator && performanceIndicator.value)
    displayedValue = formatNumberValues(performanceIndicator.value).toString()
  else displayedValue = '-----'

  let perf: number | null = null
  if (
    performanceIndicator &&
    performanceIndicator.value &&
    performanceIndicator.compareValue
  ) {
    perf =
      100 * (performanceIndicator.value / performanceIndicator.compareValue - 1)
  }
  const perfString = perf ? formatNumberValues(perf) : ''

  let perfStatus = 'error'
  if (perf === null) perfStatus = 'nodata'
  else if (perf === 0) perfStatus = 'zero'
  else if (perf > 0) perfStatus = 'positive'
  else if (perf < 0) perfStatus = 'negative'

  return (
    <NavLink
      className="fpi-link"
      to={`/consumption/${t(
        'FLUID.' + FluidType[fluidType] + '.NAME'
      ).toLowerCase()}`}
    >
      <StyledCard fluidType={fluidType}>
        <div className="fpi">
          <div className="fpi-left">
            <div className="fpi-title card-title-on">
              {t('FLUID.' + FluidType[fluidType] + '.LABEL')}
            </div>
            <div className="fpi-content">
              <StyledIcon
                className="fpi-content-icon"
                icon={iconType}
                size={50}
              />
              <div className="fpi-content-perf">
                <div className="fpi-content-perf-result card-result">
                  <span>{displayedValue}</span>
                  <span className="card-indicator">
                    {t('FLUID.' + FluidType[fluidType] + '.UNIT')}
                  </span>
                </div>
                {perfStatus === 'positive' ||
                perfStatus === 'negative' ||
                perfStatus === 'zero' ? (
                  <div className="fpi-content-perf-indicator card-text">
                    <span
                      className={`fpi-content-perf-indicator-kpi ${perfStatus} card-text-bold`}
                    >
                      {perfStatus === 'positive' ? '+' : ''}
                      {perfString}%
                    </span>
                    <span> / {timePeriodText}</span>
                  </div>
                ) : (
                  <div className="fpi-content-perf-indicator card-text">
                    <div> {t('INDICATOR.ERROR_NO_COMPARE')} </div>
                    <div> {t('INDICATOR.ERROR_NO_COMPARE_REASON')} </div>
                  </div>
                )}
              </div>
            </div>
          </div>
          <div className="fpi-right">
            <StyledIcon icon={BlackArrowIcon} size={18} />
          </div>
        </div>
      </StyledCard>
    </NavLink>
  )
}

export default translate()(FluidPerformanceIndicator)
